requirejs.config({
    'baseUrl': '../lib',
    'paths': {
        'leaflet.wms': '../dist/leaflet.wms' //.js'
    }
});

define(['leaflet', 'leaflet.wms'],
function(L, wms) {

var tiledMap = createMap('tiled-map', true);

function createMap(div, tiled) {
    // Map configuration
    var map = L.map(div);
    map.setView([-32.46461, 151.50146], 6);

    var basemaps = {
        'Basemap': basemap().addTo(map)
    };

    // Add WMS source/layers
    var source = wms.source(
        "http://localhost:8080/geoserver/GIS/wms",
        {
            "format": "image/png",
            "transparent": "true",
            //"attribution": "<a href='http://ows.terrestris.de/'>terrestris</a>",
            "info_format": "text/html",
            "tiled": tiled
        }        
    );

    var layers = {
        //'Topographic': source.getLayer("sfdem").addTo(map),
        'dem': source.getLayer("wind_speed").addTo(map)
    };

    // Create layer control
    L.control.layers(basemaps, layers).addTo(map);

    return map;
}

function basemap() {
    // maps.stamen.com
    //var attr = 'Map tiles by <a href="http://stamen.com">Stamen Design</a>, under <a href="http://creativecommons.org/licenses/by/3.0">CC BY 3.0</a>. Data by <a href="http://openstreetmap.org">OpenStreetMap</a>, under <a href="http://www.openstreetmap.org/copyright">ODbL</a>.';
    return L.tileLayer("http://map.geoq.cn/ArcGIS/rest/services/ChinaOnlineStreetPurplishBlue/MapServer/tile/{z}/{y}/{x}", {
        //opacity: 0.1,
        //attribution: attr
    });
}

function blank() {
    var layer = new L.Layer();
    layer.onAdd = layer.onRemove = function() {};
    return layer;
}

// Export maps for console experimentation
return {
    'maps': {
        'tiled': tiledMap
    }
};

});

